@@ -1,6 +1,6 @@
 
 """
-The :mod:`gccov.coverm` plot scatter bubbles.
+The :mod:`gccov.coverm` pile up coverm.
 """
 
 # Author: Jie Li <mm.jlli6t@gmail.com>
@@ -19,8 +19,5 @@ class coverm:
 
 	def run(self):
 		cmd = 'coverm contig --bam-files %s --methods mean --min-covered-fraction 0 --output-format dense --contig-end-exclusion 0 > %s' % (self.bam, self.outfile)
-		cmd = ['coverm', 'contig', '--bam-files', self.bam, '--methods', 'mean',
-				'--min-covered-fraction', '0', '--output-format', 'dense',
-				'--contig-end-exclusion', '0']
 		gt_exe.exe_cmd(cmd, shell=True)
 		gt_file.check_file_exist(self.outfile, check_empty=True)
